//--------------------------------------------------------------
// File     : main.c
// Datum    : 14.09.2013
// Version  : 1.0
// Autor    : UB
// EMail    : mc-4u(@)t-online.de
// Web      : www.mikrocontroller-4u.de
// CPU      : STM32F4
// IDE      : CooCox CoIDE 1.7.4
// GCC      : 4.7 2012q4
// Module   : CMSIS_BOOT, M4_CMSIS_CORE
// Funktion : Demo der CAN-LoLevel-Library
// Hinweis  : Diese zwei Files muessen auf 8MHz stehen
//              "cmsis_boot/stm32f4xx.h"
//              "cmsis_boot/system_stm32f4xx.c"
//--------------------------------------------------------------

#include "main.h"
#include "stm32_ub_led.h"
#include "stm32_ub_can1.h"

int main(void)
{
  uint32_t delay=0;
  uint8_t wert=0;
  CAN1_TX_FRAME_t myTXFrame; // Puffer fr TX-Daten
  CAN1_RX_FRAME_t myRXFrame; // Puffer fr RX-Daten

  SystemInit(); // Quarz Einstellungen aktivieren

  // Init der LEDs
  UB_Led_Init();

  // Init vom CAN-1 (an PB8+PB9)
  UB_CAN1_Init();

  while(1)
  {
	  //---------------------------
	  // senden
	  //---------------------------
	  delay++;
	  if(delay>5000000) {
		  // zyklisch ein CAN-Telegramm senden
		  delay=0;
		  UB_Led_Toggle(LED_GREEN);
		  // telegramm erstellen
		  myTXFrame.can_id=0x123; // ID ist egal
		  myTXFrame.anz_bytes=1;  // ein Datenbyte wird gesendet
		  myTXFrame.data[0]=wert; // Datenwert
		  // Frame senden
		  UB_CAN1_send_std_data(myTXFrame);
		  // Datenwert wird nach jedem senden incrementiert
		  wert++;
	  }

	  //---------------------------
	  // empfangen
	  //---------------------------
	  if(UB_CAN1_receive(&myRXFrame)==CAN1_RX_READY) {
		  // es wurde etwas empfangen
		  UB_Led_Toggle(LED_BLUE);
		  // Datenbyte auswerten (nur als Demo)
		  if((myRXFrame.data[0]&0x02)!=0) {
			  // beim empfangenen Datenwert ist das Bit1 gesetzt
			  UB_Led_Toggle(LED_RED);
		  }
	  }
  }
}

